import { PieChartSweepDirection_$type } from "./PieChartSweepDirection";
import { CalloutCollisionMode_$type } from "igniteui-react-core";
import { OthersCategoryType_$type } from "igniteui-react-core";
import { AxisRangeBufferMode_$type } from "./AxisRangeBufferMode";
import { RadialLabelMode_$type } from "igniteui-react-core";
import { CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgrRadialBaseChart } from "./igr-radial-base-chart";
import { ensureEnum, brushToString, stringToBrush, ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * Represents a base class for PieBase chart control that can plot scatter data
*/
export class IgrDataPieBaseChart extends IgrRadialBaseChart {
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets or sets the label format for the slices.
    */
    get sliceLabelFormat() {
        return this.i.ais;
    }
    set sliceLabelFormat(v) {
        this.i.ais = v;
    }
    /**
     * Gets or sets the format specifiers to use with the labels for the slices.
    */
    get sliceLabelFormatSpecifiers() {
        return this.i.agc;
    }
    set sliceLabelFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.agc = v;
    }
    /**
     * Gets or sets the label format for the LegendSlices.
    */
    get legendSliceLabelFormat() {
        return this.i.aic;
    }
    set legendSliceLabelFormat(v) {
        this.i.aic = v;
    }
    /**
     * Gets or sets the format specifiers to use with the labels for the LegendSlices.
    */
    get legendSliceLabelFormatSpecifiers() {
        return this.i.aga;
    }
    set legendSliceLabelFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.aga = v;
    }
    /**
     * Gets or sets the label format for the OthersSlices.
    */
    get othersSliceLabelFormat() {
        return this.i.ail;
    }
    set othersSliceLabelFormat(v) {
        this.i.ail = v;
    }
    /**
     * Gets or sets the format specifiers to use with the labels for the OthersSlices.
    */
    get othersSliceLabelFormatSpecifiers() {
        return this.i.agb;
    }
    set othersSliceLabelFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.agb = v;
    }
    /**
     * Gets or sets the label format for the LegendOthersSlices.
    */
    get legendOthersSliceLabelFormat() {
        return this.i.ah8;
    }
    set legendOthersSliceLabelFormat(v) {
        this.i.ah8 = v;
    }
    /**
     * Gets or sets the format specifiers to use with the labels for the LegendOthersSlices.
    */
    get legendOthersSliceLabelFormatSpecifiers() {
        return this.i.af9;
    }
    set legendOthersSliceLabelFormatSpecifiers(v) {
        if (v && !Array.isArray(v) && typeof (v) == "string") {
            const re = /\s*(?:,|\s|$)\s*/gm;
            v = v.split(re);
        }
        this.i.af9 = v;
    }
    /**
     * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
     * a value between 0.0 and 1.0.
    */
    get innerExtent() {
        return this.i.ahh;
    }
    set innerExtent(v) {
        this.i.ahh = +v;
    }
    /**
     * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
     * a value between 0.0 and 1.0.
    */
    get sweepDirection() {
        return this.i.ago;
    }
    set sweepDirection(v) {
        this.i.ago = ensureEnum(PieChartSweepDirection_$type, v);
    }
    /**
     * Defines the positioning mode of the slice labels for the pie chart.
    */
    get sliceLabelPositionMode() {
        return this.i.agg;
    }
    set sliceLabelPositionMode(v) {
        this.i.agg = ensureEnum(CalloutCollisionMode_$type, v);
    }
    /**
     * Gets or sets the light color to use for slice labels.
    */
    get lightSliceLabelColor() {
        return brushToString(this.i.ajk);
    }
    set lightSliceLabelColor(v) {
        this.i.ajk = stringToBrush(v);
    }
    /**
     * Gets or sets the Dark color to use for slice labels.
    */
    get darkSliceLabelColor() {
        return brushToString(this.i.ajj);
    }
    set darkSliceLabelColor(v) {
        this.i.ajj = stringToBrush(v);
    }
    /**
     * Gets or sets the overridden value member path to use.
    */
    get valueMemberPath() {
        return this.i.ai8;
    }
    set valueMemberPath(v) {
        this.i.ai8 = v;
    }
    /**
     * Gets or sets whether to use numeric or percent-based threshold value.
    */
    get othersCategoryType() {
        return this.i.agm;
    }
    set othersCategoryType(v) {
        this.i.agm = ensureEnum(OthersCategoryType_$type, v);
    }
    /**
     * Gets or sets the threshold value that determines if slices are grouped into the Others slice.
    */
    get othersCategoryThreshold() {
        return this.i.ahi;
    }
    set othersCategoryThreshold(v) {
        this.i.ahi = +v;
    }
    /**
     * Gets or sets the label of the Others slice.
    */
    get othersCategoryText() {
        return this.i.aih;
    }
    set othersCategoryText(v) {
        this.i.aih = v;
    }
    /**
     * Gets or sets the overridden value member path to use.
    */
    get labelMemberPath() {
        return this.i.ah6;
    }
    set labelMemberPath(v) {
        this.i.ah6 = v;
    }
    /**
     * Gets or sets whether the axis should favor emitting a label at the end of the scale.
    */
    get valueAxisFavorLabellingScaleEnd() {
        return this.i.ag3;
    }
    set valueAxisFavorLabellingScaleEnd(v) {
        this.i.ag3 = ensureBool(v);
    }
    /**
     * Gets or sets how the numeric axis will adjust its range buffer to less closely fix the data from the series.
    */
    get valueAxisAutoRangeBufferMode() {
        return this.i.age;
    }
    set valueAxisAutoRangeBufferMode(v) {
        this.i.age = ensureEnum(AxisRangeBufferMode_$type, v);
    }
    /**
     * Gets or sets the frequency of displayed labels along the X-axis.
     * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
    */
    get angleAxisInterval() {
        return this.i.ahf;
    }
    set angleAxisInterval(v) {
        this.i.ahf = +v;
    }
    /**
     * Gets or sets the frequency of displayed minor lines along the X-axis.
     * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
    */
    get angleAxisMinorInterval() {
        return this.i.ahg;
    }
    set angleAxisMinorInterval(v) {
        this.i.ahg = +v;
    }
    /**
     * Gets or sets the distance between each label and grid line along the Y-axis.
    */
    get valueAxisInterval() {
        return this.i.ahn;
    }
    set valueAxisInterval(v) {
        this.i.ahn = +v;
    }
    /**
     * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
     * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
    */
    get valueAxisIsLogarithmic() {
        return this.i.ag4;
    }
    set valueAxisIsLogarithmic(v) {
        this.i.ag4 = ensureBool(v);
    }
    /**
     * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
     * This property is effective only when ValueAxisIsLogarithmic is true.
    */
    get valueAxisLogarithmBase() {
        return this.i.ahs;
    }
    set valueAxisLogarithmBase(v) {
        this.i.ahs = +v;
    }
    /**
     * Gets or sets the data value corresponding to the minimum value of the Y-axis.
    */
    get valueAxisMinimumValue() {
        return this.i.ahp;
    }
    set valueAxisMinimumValue(v) {
        this.i.ahp = +v;
    }
    /**
     * Gets or sets the data value corresponding to the maximum value of the Y-axis.
    */
    get valueAxisMaximumValue() {
        return this.i.aho;
    }
    set valueAxisMaximumValue(v) {
        this.i.aho = +v;
    }
    /**
     * Gets or sets the frequency of displayed minor lines along the Y-axis.
    */
    get valueAxisMinorInterval() {
        return this.i.ahq;
    }
    set valueAxisMinorInterval(v) {
        this.i.ahq = +v;
    }
    /**
     * Gets the current minimum value for the Y-axis.
    */
    get valueAxisActualMinimum() {
        return this.i.ahm;
    }
    /**
     * Gets the current maximum value for the Y-axis.
    */
    get valueAxisActualMaximum() {
        return this.i.ahl;
    }
    /**
     * Gets or sets the extent of the chart's radius. Value between 0 and 1.
    */
    get radiusExtent() {
        return this.i.ahj;
    }
    set radiusExtent(v) {
        this.i.ahj = +v;
    }
    /**
     * Gets or sets the start angle to use for the pie chart measured in degrees from the positive x axis.
    */
    get startAngle() {
        return this.i.ahk;
    }
    set startAngle(v) {
        this.i.ahk = +v;
    }
    /**
     * Gets or sets the label of the Others slice.
    */
    get sliceLabelContentSeparator() {
        return this.i.aiq;
    }
    set sliceLabelContentSeparator(v) {
        this.i.aiq = v;
    }
    /**
     * Gets or sets the label of the Others slice.
    */
    get sliceLabelContentMode() {
        return this.i.agu;
    }
    set sliceLabelContentMode(v) {
        this.i.agu = ensureEnum(RadialLabelMode_$type, v);
    }
    /**
     * Gets or sets the label of the Others slice.
    */
    get legendSliceLabelContentMode() {
        return this.i.agt;
    }
    set legendSliceLabelContentMode(v) {
        this.i.agt = ensureEnum(RadialLabelMode_$type, v);
    }
    /**
     * Gets or sets whether to favor labelling the end of the scale.
    */
    get angleAxisFavorLabellingScaleEnd() {
        return this.i.ag0;
    }
    set angleAxisFavorLabellingScaleEnd(v) {
        this.i.ag0 = ensureBool(v);
    }
    /**
     * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
    */
    get valueAxisAbbreviateLargeNumbers() {
        return this.i.ag2;
    }
    set valueAxisAbbreviateLargeNumbers(v) {
        this.i.ag2 = ensureBool(v);
    }
    /**
     * Gets or sets collision avoidance between markers on series that support this behaviour.
    */
    get markerCollision() {
        return this.i.agi;
    }
    set markerCollision(v) {
        this.i.agi = ensureEnum(CollisionAvoidanceType_$type, v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.sliceLabelFormatSpecifiers != null && arrayFindByName(this.sliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.sliceLabelFormatSpecifiers, name);
        }
        if (this.legendSliceLabelFormatSpecifiers != null && arrayFindByName(this.legendSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.legendSliceLabelFormatSpecifiers, name);
        }
        if (this.othersSliceLabelFormatSpecifiers != null && arrayFindByName(this.othersSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.othersSliceLabelFormatSpecifiers, name);
        }
        if (this.legendOthersSliceLabelFormatSpecifiers != null && arrayFindByName(this.legendOthersSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.legendOthersSliceLabelFormatSpecifiers, name);
        }
        return null;
    }
}
