import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { RadialLabelMode_$type } from "igniteui-react-core";
import { CategoryTransitionInMode_$type } from "./CategoryTransitionInMode";
import { IgrCategoryAngleAxis } from "./igr-category-angle-axis";
import { IgrNumericRadiusAxis } from "./igr-numeric-radius-axis";
import { IgrAssigningRadialStyleEventArgs } from "./igr-assigning-radial-style-event-args";
import { IgrAssigningRadialMarkerStyleEventArgs } from "./igr-assigning-radial-marker-style-event-args";
import { IgrMarkerSeries } from "./igr-marker-series";
import { ensureEnum, ensureBool, arrayFindByName, toPoint } from "igniteui-react-core";
/**
 * Represents the base class for all IgxDataChartComponent radial series
*/
var IgrRadialBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialBase, _super);
    function IgrRadialBase(props) {
        var _this = _super.call(this, props) || this;
        _this._angleAxisName = null;
        _this._valueAxisName = null;
        _this._assigningRadialStyle = null;
        _this._assigningRadialStyle_wrapped = null;
        _this._assigningRadialMarkerStyle = null;
        _this._assigningRadialMarkerStyle_wrapped = null;
        return _this;
    }
    Object.defineProperty(IgrRadialBase.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutLabelPrecision", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.zu;
        },
        set: function (v) {
            this.i.zu = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutPercentagePrecision", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.zv;
        },
        set: function (v) {
            this.i.zv = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutLabelValueSeparator", {
        /**
         * Gets or sets the labelling mode to use for the auto callouts in preference to their mode.
        */
        get: function () {
            return this.i.z3;
        },
        set: function (v) {
            this.i.z3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "legendRadialLabelMode", {
        /**
         * Gets or sets the labelling mode to use for the auto callouts in preference to their mode.
        */
        get: function () {
            return this.i.y5;
        },
        set: function (v) {
            this.i.y5 = ensureEnum(RadialLabelMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutRadialLabelMode", {
        /**
         * Gets or sets the labelling mode to use for the auto callouts in preference to their mode.
        */
        get: function () {
            return this.i.y4;
        },
        set: function (v) {
            this.i.y4 = ensureEnum(RadialLabelMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutOthersLabelFormat", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.z5;
        },
        set: function (v) {
            this.i.z5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "autoCalloutOthersLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the auto callouts for the others category.
        */
        get: function () {
            return this.i.yd;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.yd = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "proportionalRadialLabelFormat", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.aar;
        },
        set: function (v) {
            this.i.aar = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "proportionalRadialLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the auto callouts for the others category.
        */
        get: function () {
            return this.i.yi;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.yi = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "legendProportionalRadialLabelFormat", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.aah;
        },
        set: function (v) {
            this.i.aah = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "legendProportionalRadialLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the auto callouts for the others category.
        */
        get: function () {
            return this.i.yf;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.yf = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "othersProportionalRadialLabelFormat", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.aao;
        },
        set: function (v) {
            this.i.aao = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "othersProportionalRadialLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the auto callouts for the others category.
        */
        get: function () {
            return this.i.yh;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.yh = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "othersLegendProportionalRadialLabelFormat", {
        /**
         * Gets or sets the format string to use for the auto callout labels for the others category.
        */
        get: function () {
            return this.i.aal;
        },
        set: function (v) {
            this.i.aal = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "othersLegendProportionalRadialLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the auto callouts for the others category.
        */
        get: function () {
            return this.i.yg;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.yg = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "isRadial", {
        /**
         * Checks if this series is a radial series
        */
        get: function () {
            return this.i.fr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "isCustomRadialStyleAllowed", {
        /**
         * Gets or sets whether this Radial series should allow custom style overrides of its individual visuals.
        */
        get: function () {
            return this.i.zi;
        },
        set: function (v) {
            this.i.zi = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "isCustomRadialMarkerStyleAllowed", {
        /**
         * Gets or sets whether this Radial series should allow custom style overrides of its individual marker visuals.
        */
        get: function () {
            return this.i.zh;
        },
        set: function (v) {
            this.i.zh = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "transitionInMode", {
        /**
         * Gets or sets the method by which to animate the data into the chart when the chart data source is swapped.
         * Note: Transitions are not currently supported for stacked series.
        */
        get: function () {
            return this.i.yt;
        },
        set: function (v) {
            this.i.yt = ensureEnum(CategoryTransitionInMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "isTransitionInEnabled", {
        /**
         * Gets or sets whether the series should transition into the plot area when a new data source is assigned.
         * Note: Transitions are not currently supported for stacked series.
        */
        get: function () {
            return this.i.zj;
        },
        set: function (v) {
            this.i.zj = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "angleAxis", {
        /**
         * Gets the effective angle axis for the current series object.
        */
        get: function () {
            var r = this.i.yq;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrCategoryAngleAxis._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.yq = null : this.i.yq = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "angleAxisName", {
        /**
        * Gets or sets the name to use to resolve angleAxis from markup.
        */
        get: function () {
            return this._angleAxisName;
        },
        set: function (v) {
            this._angleAxisName = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "valueAxis", {
        /**
         * Gets the effective value axis for the current series object.
        */
        get: function () {
            var r = this.i.yv;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrNumericRadiusAxis._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.yv = null : this.i.yv = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "valueAxisName", {
        /**
        * Gets or sets the name to use to resolve valueAxis from markup.
        */
        get: function () {
            return this._valueAxisName;
        },
        set: function (v) {
            this._valueAxisName = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "clipSeriesToBounds", {
        /**
         * Gets or sets whether to clip the series to the bounds.
         * Setting this property to true will decrease chart performance.
        */
        get: function () {
            return this.i.zg;
        },
        set: function (v) {
            this.i.zg = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrRadialBase.prototype.bindAxes = function (axes) {
        _super.prototype.bindAxes.call(this, axes);
        for (var i = 0; i < axes.length; i++) {
            if (this.angleAxisName && this.angleAxisName.length > 0 &&
                axes[i].name == this.angleAxisName) {
                this.angleAxis = axes[i];
            }
        }
        for (var i = 0; i < axes.length; i++) {
            if (this.valueAxisName && this.valueAxisName.length > 0 &&
                axes[i].name == this.valueAxisName) {
                this.valueAxis = axes[i];
            }
        }
    };
    IgrRadialBase.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.autoCalloutOthersLabelFormatSpecifiers != null && arrayFindByName(this.autoCalloutOthersLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.autoCalloutOthersLabelFormatSpecifiers, name);
        }
        if (this.proportionalRadialLabelFormatSpecifiers != null && arrayFindByName(this.proportionalRadialLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.proportionalRadialLabelFormatSpecifiers, name);
        }
        if (this.legendProportionalRadialLabelFormatSpecifiers != null && arrayFindByName(this.legendProportionalRadialLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.legendProportionalRadialLabelFormatSpecifiers, name);
        }
        if (this.othersProportionalRadialLabelFormatSpecifiers != null && arrayFindByName(this.othersProportionalRadialLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.othersProportionalRadialLabelFormatSpecifiers, name);
        }
        if (this.othersLegendProportionalRadialLabelFormatSpecifiers != null && arrayFindByName(this.othersLegendProportionalRadialLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.othersLegendProportionalRadialLabelFormatSpecifiers, name);
        }
        if (this.angleAxis && this.angleAxis.name && this.angleAxis.name == name) {
            return this.angleAxis;
        }
        if (this.valueAxis && this.valueAxis.name && this.valueAxis.name == name) {
            return this.valueAxis;
        }
        return null;
    };
    IgrRadialBase.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.angleAxis && this.angleAxis._styling) {
            this.angleAxis._styling(container, component, this);
        }
        if (this.valueAxis && this.valueAxis._styling) {
            this.valueAxis._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Determine if object can be used as ValueAxis
    
    * @param axis  * The object to check
    */
    IgrRadialBase.prototype.canUseAsValueAxis = function (axis) {
        var iv = this.i.zf(axis);
        return (iv);
    };
    /**
     * Determine if object can be used as AngleAxis
    
    * @param axis  * The object to check
    */
    IgrRadialBase.prototype.canUseAsAngleAxis = function (axis) {
        var iv = this.i.ze(axis);
        return (iv);
    };
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    IgrRadialBase.prototype.getItem = function (world) {
        var iv = this.i.kl(toPoint(world));
        return (iv);
    };
    /**
     * Gets the angle to the provided world position from the center of the radial series.
    
    * @param world  * The world position to get the angle for
    */
    IgrRadialBase.prototype.getAngleFromWorld = function (world) {
        var iv = this.i.zp(toPoint(world));
        return (iv);
    };
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    IgrRadialBase.prototype.getExactItemIndex = function (world) {
        var iv = this.i.ip(toPoint(world));
        return (iv);
    };
    /**
     * Get the index of the item near the provided world coordinates.
    
    * @param world  * The world coordinates for which to getch the item index.
    */
    IgrRadialBase.prototype.getItemIndex = function (world) {
        var iv = this.i.j1(toPoint(world));
        return (iv);
    };
    /**
     * Scrolls the specified item into the view.
    
    * @param item  * The item to scroll into view.
    */
    IgrRadialBase.prototype.scrollIntoView = function (item) {
        var iv = this.i.gb(item);
        return (iv);
    };
    /**
     * Returns the offset value for this series if grouped on a category axis.
    
    */
    IgrRadialBase.prototype.getOffsetValue = function () {
        var iv = this.i.getOffsetValue();
        return (iv);
    };
    /**
     * Returns the width of the category grouping this series is in.
    
    */
    IgrRadialBase.prototype.getCategoryWidth = function () {
        var iv = this.i.getCategoryWidth();
        return (iv);
    };
    Object.defineProperty(IgrRadialBase.prototype, "assigningRadialStyle", {
        /**
         * Event raised when Assigning Category Style
        */
        get: function () {
            return this._assigningRadialStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningRadialStyle_wrapped !== null) {
                this.i.assigningRadialStyle = delegateRemove(this.i.assigningRadialStyle, this._assigningRadialStyle_wrapped);
                this._assigningRadialStyle_wrapped = null;
                this._assigningRadialStyle = null;
            }
            this._assigningRadialStyle = ev;
            this._assigningRadialStyle_wrapped = function (o, e) {
                var outerArgs = new IgrAssigningRadialStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningRadialStyle) {
                    _this.beforeAssigningRadialStyle(_this, outerArgs);
                }
                if (_this._assigningRadialStyle) {
                    _this._assigningRadialStyle(_this, outerArgs);
                }
            };
            this.i.assigningRadialStyle = delegateCombine(this.i.assigningRadialStyle, this._assigningRadialStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialBase.prototype, "assigningRadialMarkerStyle", {
        /**
         * Event raised when Assigning Radial Marker Style
        */
        get: function () {
            return this._assigningRadialMarkerStyle;
        },
        set: function (ev) {
            var _this = this;
            if (this._assigningRadialMarkerStyle_wrapped !== null) {
                this.i.assigningRadialMarkerStyle = delegateRemove(this.i.assigningRadialMarkerStyle, this._assigningRadialMarkerStyle_wrapped);
                this._assigningRadialMarkerStyle_wrapped = null;
                this._assigningRadialMarkerStyle = null;
            }
            this._assigningRadialMarkerStyle = ev;
            this._assigningRadialMarkerStyle_wrapped = function (o, e) {
                var outerArgs = new IgrAssigningRadialMarkerStyleEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeAssigningRadialMarkerStyle) {
                    _this.beforeAssigningRadialMarkerStyle(_this, outerArgs);
                }
                if (_this._assigningRadialMarkerStyle) {
                    _this._assigningRadialMarkerStyle(_this, outerArgs);
                }
            };
            this.i.assigningRadialMarkerStyle = delegateCombine(this.i.assigningRadialMarkerStyle, this._assigningRadialMarkerStyle_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrRadialBase;
}(IgrMarkerSeries));
export { IgrRadialBase };
